import json
from typing import Optional
from cryptography.hazmat.primitives.asymmetric import rsa
from kalshi_client.connector import Connector


class KalshiClient(Connector):
    def __init__(self, key_id: str, private_key: rsa.RSAPrivateKey, 
                 exchange_api_base: str = 'https://api.elections.kalshi.com/trade-api/v2',
                 rate_limit: int = 10):
        super().__init__(
            exchange_api_base,
            key_id,
            private_key,
            rate_limit
        )
        """
        Initializes the KalshiClient.

        Args:
            key_id (str): The key id for the client.
            private_key (rsa.RSAPrivateKey): The private key for the client.
            exchange_api_base (str, optional): The base URL for the Kalshi API. Defaults to 'https://api.elections.kalshi.com/trade-api/v2'.
            rate_limit (int, optional): The rate limit for the client (per second). Defaults to 10.
        """
        self.key_id = key_id
        self.private_key = private_key
        self.exchange_url = "/exchange"
        self.markets_url = "/markets"
        self.events_url = "/events"
        self.series_url = "/series"
        self.portfolio_url = "/portfolio"

    def logout(self,):
        result = self.post("/logout")
        return result

    def get_exchange_status(self,):
        result = self.get(self.exchange_url + "/status")
        return result

    # market endpoints!

    def get_markets(self,
                        limit:Optional[int]=None,
                        cursor:Optional[str]=None,
                        event_ticker:Optional[str]=None,
                        series_ticker:Optional[str]=None,
                        max_close_ts:Optional[int]=None,
                        min_close_ts:Optional[int]=None,
                        status:Optional[str]=None,
                        tickers:Optional[str]=None,
                            ):
        """
        Gets the markets based on the specified query parameters.

        Args:
            limit (Optional[int], optional): Specifies the number of results to return per page. Must be between 1 and 1000. Defaults to 100.
            cursor (Optional[str], optional): A pagination pointer to the next page of records. If provided, the API will return the next page containing the number of records specified in the `limit` parameter. If not provided, the API will return the first page of the results for the query. Note: The `cursor` does not store filters. Therefore, any filters (e.g., `event_ticker`, `series_ticker`, `max_close_ts`, `min_close_ts`, or `status`) passed in the original query must be passed again. Defaults to None.
            event_ticker (Optional[str], optional): Filters markets by the specified event ticker. Defaults to None.
            series_ticker (Optional[str], optional): Filters markets by the specified series ticker. Defaults to None.
            max_close_ts (Optional[int], optional): Filters markets with a close timestamp less than or equal to the specified timestamp. Defaults to None.
            min_close_ts (Optional[int], optional): Filters markets with a close timestamp greater than or equal to the specified timestamp. Defaults to None.
            status (Optional[str], optional): Filters markets by their status. Valid values include: `unopened`, `open`, `closed`, `settled`. Defaults to None.
            tickers (Optional[str], optional): Filters markets by the specified tickers, as a comma separated list. Defaults to None.

        Returns:
            dict: A dictionary containing the retrieved markets and associated metadata
        """
        return self.get(self.markets_url + self.query_generation(locals()))

    def get_events(self,
                        limit:Optional[int]=None,
                        cursor:Optional[str]=None,
                        series_ticker:Optional[str]=None,
                        status:Optional[str]=None,
                        with_nested_markets:Optional[bool]=None,
                        ):
        """
        Gets the events based on the specified query parameters.

        Args:
            limit (Optional[int], optional): Specifies the number of results to return per page. Must be between 1 and 1000. Defaults to 100.
            cursor (Optional[str], optional): A pagination pointer to the next page of records. If provided, the API will return the next page containing the number of records specified in the `limit` parameter. If not provided, the API will return the first page of the results for the query. Note: The `cursor` does not store filters. Therefore, any filters (e.g., `series_ticker` or `status`) passed in the original query must be passed again. Defaults to None.
            series_ticker (Optional[str], optional): Filters events by the specified series ticker. Defaults to None.
            status (Optional[str], optional): Filters events by their status. Valid values include: `unopened`, `open`, `closed`, `settled`. Defaults to None.
            with_nested_markets (Optional[bool], optional): If `True`, retrieves nested markets within the event. Defaults to None.

        Returns:
            dict: A dictionary containing the retrieved events and associated metadata
        """
        return self.get(self.events_url + self.query_generation(locals()))

    def get_market_url(self, 
                        ticker:str):
        """
        Get the URL for a specific market based on its ticker.
        
        Args:
            ticker (str): The market ticker.
        
        Returns:
            str: The URL for the specified market.
        """
        return self.markets_url+'/'+ticker

    def get_market(self, 
                    ticker:str):
        market_url = self.get_market_url(ticker=ticker)
        dictr = self.get(market_url)
        return dictr

    def get_event(self, 
                    event_ticker: str,
                    with_nested_markets: Optional[bool] = None):
        """
        Get the event based on the event ticker.

        Args:
            event_ticker (str): The event ticker.
            with_nested_markets (Optional[bool], optional): If `True`, retrieves nested markets within the event. Defaults to None.
        
        Returns:
            dict: A dictionary containing the retrieved event and associated metadata
        """
        if with_nested_markets is not None:
            return self.get(f'{self.events_url}/{event_ticker}?with_nested_markets={with_nested_markets}')
        return self.get(f'{self.events_url}/{event_ticker}')

    def get_series(self, 
                    series_ticker:str):
        dictr = self.get(self.series_url + '/' + series_ticker)
        return dictr

    def get_market_candlesticks(self, 
                                ticker: str,
                                series_ticker: str,
                                start_ts: int,
                                end_ts: int,
                                period_interval: int):
        """
        Get the candlesticks for a specific market based on the specified query parameters.

        Args:
            ticker (str): The market ticker.
            series_ticker (str): The series ticker.
            start_ts (int): The start timestamp in unix seconds.
            end_ts (int): The end timestamp in unix seconds.
            period_interval (int): Specifies the length of each candlestick period, in minutes. Must be one minute, one hour, or one day.
        
        Returns:
            dict: A dictionary containing the retrieved candlesticks and associated metadata.
        """
        params = {
            'start_ts': start_ts,
            'end_ts': end_ts,
            'period_interval': period_interval
        }
        query_string = self.query_generation(params)
        url = f'/series/{series_ticker}/markets/{ticker}/candlesticks{query_string}'
        return self.get(url)

    def get_orderbook(self, 
                        ticker:str,
                        depth:Optional[int]=None,
                        ):
        """
        Get the orderbook for a specific market based on the specified query parameters.
        
        Args:
            ticker (str): The market ticker.
            depth (Optional[int], optional): Depth specifies the maximum number of orderbook price levels you want to see for either side. Only the highest (most relevant) price level are kept.
        
        Returns:
            dict: A dictionary containing the retrieved orderbook and associated metadata
        """
        relevant_params = {k: v for k, v in locals().items() if k != 'ticker'}                            
        query_string = self.query_generation(params = relevant_params)
        market_url = self.get_market_url(ticker)
        return self.get(market_url + "/orderbook" + query_string)

    def get_trades(self,
                    ticker:Optional[str]=None,
                    limit:Optional[int]=None,
                    cursor:Optional[str]=None,
                    max_ts:Optional[int]=None,
                    min_ts:Optional[int]=None,
                    ):
        
        query_string = self.query_generation(locals())
        if ticker:
            if len(query_string):
                query_string += '&'
            else:
                query_string += '?'
            query_string += "ticker=" + ticker
            
        trades_url = self.markets_url + '/trades'
        dictr = self.get(trades_url + query_string)
        return dictr

    # portfolio endpoints!

    def get_balance(self,):
        return self.get(self.portfolio_url + '/balance')

    def create_order(self,
                 ticker: str,
                 client_order_id: str,
                 side: str,
                 action: str,
                 count: int,
                 type: str,
                 yes_price: Optional[int] = None,
                 no_price: Optional[int] = None,
                 expiration_ts: Optional[int] = None,
                 sell_position_floor: Optional[int] = None,
                 buy_max_cost: Optional[int] = None,
                 ):

        relevant_params = {k: v for k, v in locals().items() if k != 'self' and v}
        order_json = json.dumps(relevant_params)
        orders_url = self.portfolio_url + '/orders'
        result = self.post(path=orders_url, body=order_json)
        return result


    def batch_create_orders(self, 
                                orders:list
        ):
        orders_json = json.dumps({'orders': orders})
        batched_orders_url = self.portfolio_url + '/orders/batched'
        result = self.post(path = batched_orders_url, body = orders_json)
        return result

    def decrease_order(self, 
                        order_id:str,
                        reduce_by:int,
                        ):
        order_url = self.portfolio_url + '/orders/' + order_id
        decrease_json = json.dumps({'reduce_by': reduce_by})
        result = self.post(path = order_url + '/decrease', body = decrease_json)
        return result

    def cancel_order(self,
                        order_id:str
                        ):
        order_url = self.portfolio_url + '/orders/' + order_id
        result = self.delete(path = order_url)
        return result

    def batch_cancel_orders(self, 
                                order_ids:list
        ):
        order_ids_json = json.dumps({"ids":order_ids})
        batched_orders_url = self.portfolio_url + '/orders/batched'
        result = self.delete(path = batched_orders_url, body = order_ids_json)
        return result

    def get_fills(self,
                        ticker:Optional[str]=None,
                        order_id:Optional[str]=None,
                        min_ts:Optional[int]=None,
                        max_ts:Optional[int]=None,
                        limit:Optional[int]=None,
                        cursor:Optional[str]=None):

        fills_url = self.portfolio_url + '/fills'
        query_string = self.query_generation(params={k: v for k,v in locals().items()})
        dictr = self.get(fills_url + query_string)
        return dictr
    
    def get_orders(self,
                        ticker:Optional[str]=None,
                        event_ticker:Optional[str]=None,
                        min_ts:Optional[int]=None,
                        max_ts:Optional[int]=None,
                        limit:Optional[int]=None,
                        cursor:Optional[str]=None
                        ):
        orders_url = self.portfolio_url + '/orders'
        query_string = self.query_generation(params={k: v for k,v in locals().items()})
        dictr = self.get(orders_url + query_string)
        return dictr
    
    def get_order(self,
                    order_id:str):
        orders_url = self.portfolio_url + '/orders'
        dictr = self.get(orders_url + '/' +  order_id)
        return dictr
    
    def get_positions(self,
                  limit: Optional[int] = None,
                  cursor: Optional[str] = None,
                  settlement_status: Optional[str] = None,
                  ticker: Optional[str] = None,
                  event_ticker: Optional[str] = None,
                  count_filter: Optional[str] = None):
        """
        Retrieve a list of positions based on the specified query parameters.

        Args
        ----------
        limit : Optional[int], default=None
            Specifies the number of results to return per page. Must be between 1 and 1000.
            Defaults to 100 if not provided.

        cursor : Optional[str], default=None
            A pagination pointer to the next page of records. 
            - If provided, the API will return the next page containing the number of records specified in the `limit` parameter.
            - If not provided, the API will return the first page of the results for the query.
            Note: The `cursor` does not store filters. Therefore, any filters (e.g., `settlement_status`, `ticker`, or `event_ticker`) passed in the original query must be passed again.

        settlement_status : Optional[str], default=None
            Filters positions based on their settlement status. Valid values include:
            - `all`: Retrieve all settlement statuses.
            - `settled`: Retrieve only settled positions.
            - `unsettled`: Retrieve only unsettled positions.
            Defaults to `unsettled`.

        ticker : Optional[str], default=None
            Filters positions by the specified ticker.

        event_ticker : Optional[str], default=None
            Filters positions by the specified event ticker.

        count_filter : Optional[str], default=None
            Restricts positions to those where any of the specified fields have non-zero values. 
            Accepts a comma-separated list of the following fields:
            - `position`: Filters positions with non-zero position values.
            - `total_traded`: Filters positions with non-zero total traded values.
            - `resting_order_count`: Filters positions with non-zero resting order count.

        Returns
        -------
        dict
            A dictionary containing the retrieved positions and associated metadata.
        """
        positions_url = self.portfolio_url + '/positions'
        query_string = self.query_generation(params={k: v for k, v in locals().items()})
        dictr = self.get(positions_url + query_string)
        return dictr


    def get_portfolio_settlements(self,
                                    limit:Optional[int]=None,
                                    cursor:Optional[str]=None,):

        positions_url = self.portfolio_url + '/settlements'
        query_string = self.query_generation(params={k: v for k,v in locals().items()})
        dictr = self.get(positions_url + query_string)
        return dictr


import pandas as pd


"""
These implementations may be very wrong, as they 
were generated with ChatGPT.
Use with caution!
"""


def calculate_rsi(candlesticks, period=14):
    """
    Calculate the Relative Strength Index (RSI) for a given price series.
    
    :param candlesticks: List of candlestick data
    :param period: Look-back period for RSI calculation (default is 14)
    :return: Latest RSI value
    """
    # Convert prices to a Pandas Series
    prices = pd.Series([i['price']['close'] for i in candlesticks])
    
    # Calculate price changes
    delta = prices.diff()
    
    # Separate gains and losses
    gains = delta.clip(lower=0)
    losses = -delta.clip(upper=0)
    
    # Calculate the average gains and losses
    avg_gains = gains.rolling(window=period, min_periods=1).mean()
    avg_losses = losses.rolling(window=period, min_periods=1).mean()
    
    # Calculate the Relative Strength (RS)
    rs = avg_gains / avg_losses
    
    # Calculate RSI
    rsi = 100 - (100 / (1 + rs))
    return rsi.iat[-1]

def calculate_sma(candlesticks, period=14):
    """
    Calculate the Simple Moving Average (SMA) for a given price series.

    :param candlesticks: List of candlestick data
    :param period: Look-back period for SMA calculation (default is 14)
    :return: Latest SMA value
    """
    prices = pd.Series([i['price']['close'] for i in candlesticks])
    sma = prices.rolling(window=period).mean()
    return sma.iat[-1]

def calculate_ema(candlesticks, period=14):
    """
    Calculate the Exponential Moving Average (EMA) for a given price series.

    :param candlesticks: List of candlestick data
    :param period: Look-back period for EMA calculation (default is 14)
    :return: Latest EMA value
    """
    prices = pd.Series([i['price']['close'] for i in candlesticks])
    ema = prices.ewm(span=period, adjust=False).mean()
    return ema.iat[-1]

def calculate_macd(candlesticks, slow_period=26, fast_period=12, signal_period=9):
    """
    Calculate the Moving Average Convergence Divergence (MACD) for a given price series.

    :param candlesticks: List of candlestick data
    :param slow_period: Period for the slow EMA (default is 26)
    :param fast_period: Period for the fast EMA (default is 12)
    :param signal_period: Period for the signal line EMA (default is 9)
    :return: Latest MACD value and signal line value
    """
    prices = pd.Series([i['price']['close'] for i in candlesticks])
    ema_fast = prices.ewm(span=fast_period, adjust=False).mean()
    ema_slow = prices.ewm(span=slow_period, adjust=False).mean()
    macd_line = ema_fast - ema_slow
    signal_line = macd_line.ewm(span=signal_period, adjust=False).mean()
    return macd_line.iat[-1], signal_line.iat[-1]

def calculate_bollinger_bands(candlesticks, period=20, num_std_dev=2):
    """
    Calculate Bollinger Bands for a given price series.

    :param candlesticks: List of candlestick data
    :param period: Look-back period for Bollinger Bands calculation (default is 20)
    :param num_std_dev: Number of standard deviations for the bands (default is 2)
    :return: Latest middle band (SMA), upper band, and lower band values
    """
    prices = pd.Series([i['price']['close'] for i in candlesticks])
    sma = prices.rolling(window=period).mean()
    std_dev = prices.rolling(window=period).std()
    upper_band = sma + (std_dev * num_std_dev)
    lower_band = sma - (std_dev * num_std_dev)
    return sma.iat[-1], upper_band.iat[-1], lower_band.iat[-1]

def calculate_stochastic_oscillator(candlesticks, period=14):
    """
    Calculate the Stochastic Oscillator for a given price series.

    :param candlesticks: List of candlestick data
    :param period: Look-back period for Stochastic Oscillator calculation (default is 14)
    :return: Latest %K value
    """
    close_prices = pd.Series([i['price']['close'] for i in candlesticks])
    low_prices = pd.Series([i['price']['low'] for i in candlesticks])
    high_prices = pd.Series([i['price']['high'] for i in candlesticks])
    lowest_low = low_prices.rolling(window=period).min()
    highest_high = high_prices.rolling(window=period).max()
    percent_k = 100 * ((close_prices - lowest_low) / (highest_high - lowest_low))
    return percent_k.iat[-1]

def calculate_atr(candlesticks, period=14):
    """
    Calculate the Average True Range (ATR) for a given price series.

    :param candlesticks: List of candlestick data
    :param period: Look-back period for ATR calculation (default is 14)
    :return: Latest ATR value
    """
    high_prices = pd.Series([i['price']['high'] for i in candlesticks])
    low_prices = pd.Series([i['price']['low'] for i in candlesticks])
    close_prices = pd.Series([i['price']['close'] for i in candlesticks])

    true_ranges = []
    for i in range(1, len(candlesticks)):
        high = high_prices.iat[i]
        low = low_prices.iat[i]
        prev_close = close_prices.iat[i - 1]
        tr = max(high - low, abs(high - prev_close), abs(low - prev_close))
        true_ranges.append(tr)
    atr_series = pd.Series(true_ranges)
    atr = atr_series.rolling(window=period).mean()
    return atr.iat[-1]

def calculate_adx(candlesticks, period=14):
    """
    Calculate the Average Directional Index (ADX) for a given price series.

    :param candlesticks: List of candlestick data
    :param period: Look-back period for ADX calculation (default is 14)
    :return: Latest ADX value
    """
    high_prices = pd.Series([i['price']['high'] for i in candlesticks])
    low_prices = pd.Series([i['price']['low'] for i in candlesticks])
    close_prices = pd.Series([i['price']['close'] for i in candlesticks])

    plus_dm = high_prices.diff()
    minus_dm = low_prices.diff().abs()
    plus_dm[plus_dm < 0] = 0
    minus_dm[minus_dm < 0] = 0

    tr_list = []
    for i in range(1, len(candlesticks)):
        high = high_prices.iat[i]
        low = low_prices.iat[i]
        prev_close = close_prices.iat[i - 1]
        tr = max(high - low, abs(high - prev_close), abs(low - prev_close))
        tr_list.append(tr)
    tr_series = pd.Series(tr_list)

    atr = tr_series.rolling(window=period).mean()

    plus_di = 100 * (plus_dm.rolling(window=period).mean() / atr)
    minus_di = 100 * (minus_dm.rolling(window=period).mean() / atr)
    dx = (abs(plus_di - minus_di) / (plus_di + minus_di)) * 100
    adx = dx.rolling(window=period).mean()
    return adx.iat[-1]

def calculate_obv(candlesticks):
    """
    Calculate the On-Balance Volume (OBV) for a given price series.

    :param candlesticks: List of candlestick data
    :return: Latest OBV value
    """
    close_prices = pd.Series([i['price']['close'] for i in candlesticks])
    volumes = pd.Series([i['volume'] for i in candlesticks])
    obv = [0]
    for i in range(1, len(close_prices)):
        if close_prices.iat[i] > close_prices.iat[i - 1]:
            obv.append(obv[-1] + volumes.iat[i])
        elif close_prices.iat[i] < close_prices.iat[i - 1]:
            obv.append(obv[-1] - volumes.iat[i])
        else:
            obv.append(obv[-1])
    return obv[-1]



import requests
from datetime import datetime
from typing import Any, Dict, Optional
from datetime import datetime
from cryptography.hazmat.primitives import hashes
from cryptography.hazmat.primitives.asymmetric import padding, rsa
from cryptography.exceptions import InvalidSignature
import time 
import base64
from kalshi_client.http_helpers import HttpError


class Connector:
    """A simple client that allows utils to call authenticated Kalshi API endpoints."""
    def __init__(
        self,
        host: str,
        key_id: str,
        private_key: rsa.RSAPrivateKey,
        rate_limit = 10,
        user_id: Optional[str] = None,
    ):
        """Initializes the client and logs in the specified user.
        Raises an HttpError if the user could not be authenticated.
        """
        self.host = host 
        self.key_id: str = key_id
        self.user_id = user_id
        self.private_key: rsa.RSAPrivateKey = private_key
        self.threshold = 1 / rate_limit
        self.session = requests.Session()
        self.session.headers.update({"Content-Type": "application/json",
                                     "KALSHI-ACCESS-KEY": self.key_id,})
        self.last_api_call = datetime.now()

    """Built in rate-limiter. We STRONGLY encourage you to keep 
    some sort of rate limiting, just in case there is a bug in your 
    code. Feel free to adjust the threshold"""
    def rate_limit(self) -> None:

        # Check if the time since the last API call is below the threshold
        elapsed_time = (datetime.now() - self.last_api_call).total_seconds()
        if elapsed_time < self.threshold:
            time.sleep(self.threshold - elapsed_time)

        # Update the last API call timestamp
        self.last_api_call = datetime.now()


    def post(self, path: str, body: dict) -> Any:
        """POSTs to an authenticated Kalshi HTTP endpoint.
        Returns the response body. Raises an HttpError on non-2XX results.
        """
        self.rate_limit()

        response = self.session.post(
            self.host + path, data=body, headers=self.request_headers("POST", path)
        )
        self.raise_if_bad_response(response)
        return response.json()

    def get(self, path: str, params: Dict[str, Any] = {}) -> Any:
        """GETs from an authenticated Kalshi HTTP endpoint.
        Returns the response body. Raises an HttpError on non-2XX results."""
        self.rate_limit()
        
        response = self.session.get(
            self.host + path, headers=self.request_headers("GET", path), params=params
        )
        self.raise_if_bad_response(response)
        return response.json()

    def delete(self, path: str, params: Dict[str, Any] = {}) -> Any:
        """Posts from an authenticated Kalshi HTTP endpoint.
        Returns the response body. Raises an HttpError on non-2XX results."""
        self.rate_limit()
        
        response = self.session.delete(
            self.host + path, headers=self.request_headers("DELETE", path), params=params
        )
        self.raise_if_bad_response(response)
        return response.json()

    def request_headers(self, method: str, path: str) -> Dict[str, Any]:
        # Generate the current timestamp in milliseconds
        timestampt_str = str(int(datetime.now().timestamp() * 1000))

        # Extract the path without query parameters
        clean_path = path.split('?', 1)[0]

        # Construct the message string for signing
        msg_string = f"{timestampt_str}{method}/trade-api/v2{clean_path}"

        # Sign the message string
        signature = self.sign_pss_text(msg_string)

        # Build headers dictionary
        headers = {
            "KALSHI-ACCESS-SIGNATURE": signature,
            "KALSHI-ACCESS-TIMESTAMP": timestampt_str,
        }
        return headers

    
    def sign_pss_text(self, text: str) -> str:
        # Before signing, we need to hash our message.
        # The hash is what we actually sign.
        # Convert the text to bytes
        message = text.encode('utf-8')
        try:
            signature = self.private_key.sign(
                message,
                padding.PSS(
                    mgf=padding.MGF1(hashes.SHA256()),
                    salt_length=padding.PSS.DIGEST_LENGTH
                ),
                hashes.SHA256()
            )
            return base64.b64encode(signature).decode('utf-8')
        except InvalidSignature as e:
            raise ValueError("RSA sign PSS failed") from e

    def raise_if_bad_response(self, response: requests.Response) -> None:
        if response.status_code not in range(200, 299):
            if response.status_code == 404:
                raise HttpError(response.reason, response.status_code, tip='Check ticker used for call if one was provided')
            elif response.status_code == 400:
                raise HttpError(response.reason, response.status_code, tip='One or more of the parameters could be wrong')
            else:
                raise HttpError(response.reason, response.status_code)
            
    def query_generation(self, params:dict) -> str:
        """
        Generate a URL query string from a dictionary of parameters.
        """
        query = '&'.join(f'{str(k)}={str(v)}' for k, v in params.items() if v)
        return f'?{query}' if query else ''


from cryptography.hazmat.primitives import serialization
from cryptography.hazmat.backends import default_backend


def load_private_key_from_file(file_path):
    with open(file_path, "rb") as key_file:
        private_key = serialization.load_pem_private_key(
            key_file.read(),
            password=None,  # or provide a password if your key is encrypted
            backend=default_backend()
        )
    return private_key





class HttpError(Exception):
    """Represents an HTTP error with reason and status code."""
    def __init__(self, reason: str, status: int, tip: str = None):
        super().__init__(reason)
        self.reason = reason
        self.status = status
        self.tip = tip

    def __str__(self) -> str:
        return f'\n\nHttpError({self.status} {self.reason})\nTip: {self.tip}\n'


from setuptools import setup, find_packages

setup(
    name="kalshi-client",
    version="0.1.6",
    description="An unofficial python client for the Kalshi API",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    author="vaguenebula",
    author_email="nebbylockedin@gmail.com",
    url="https://github.com/vaguenebula/kalshi-client",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
    install_requires=[
        "cryptography==44.0.0",
        "requests==2.32.3"
    ],
)
